<?php

class Prepear_Wprm_Util {

    public static function get_data()
    {
        $data = ['enabled' => self::is_enabled()];
        if ($data['enabled']) {
            $data['preview_url'] = self::get_preview_url();
            $data['action_buttons'] = self::get_action_buttons();
        }
        return $data;
    }

    public static function is_enabled()
    {
        $active_plugins = get_option('active_plugins');
        $all_plugins = get_plugins();
        // $wp_recipe_maker_version = null;
        foreach ($active_plugins as $plugin) {
            if ($plugin == 'wp-recipe-maker/wp-recipe-maker.php') {
                // $wp_recipe_maker_version = $all_plugins[$plugin]['Version'];
                return true;
            }
        }
    }

    private static function get_action_buttons()
    {
        $buttons = [];

        if( class_exists( 'WPRM_Template_Manager' ) ) {
            // gets the currently selected wprm template
            $template = WPRM_Template_Manager::get_template_by_type();

            if ($template) {
                $shortcodes = Prepear_ShortcodeParser::parse_shortcodes($template['html']);
                
                foreach ($shortcodes['order'] as $code) {
                    if (in_array($code, ['wprm-recipe-print', 'wprm-recipe-pin', 'wprm-recipe-add-to-collection', 'wprm-recipe-jump-to-comments'])) {
                        if (isset($shortcodes[$code])) {
                            $codeInfo = $shortcodes[$code];
                            $atts = self::get_atts_for_shortcode($codeInfo);
                            $buttons[] = [
                                'code' => $code,
                                'text' => $atts['text'],
                                'class' => $atts['class'],
                                'style' => $atts['style'],
                                'iconColor' => $atts['icon_color'],
                            ];
                        }
                    }
                }
            }
        }

        return $buttons;
    }

    private static function get_preview_url()
    {
        if( defined( 'WPRM_POST_TYPE' ) && class_exists( 'WPRM_Recipe_Manager' ) ) {
            $posts = get_posts( array(
                'post_type' => WPRM_POST_TYPE,
                'posts_per_page' => 1,
                'orderby' => 'rand',
            ) );

            $recipe_id = isset( $posts[0] ) ? $posts[0]->ID : 0;
            $recipe = WPRM_Recipe_Manager::get_recipe( $recipe_id );

            if ($recipe) {
                $post_id = $recipe->parent_post_id();
                return get_preview_post_link($post_id, ['prepear_preview' => '1']);
            }
        }

        return '';
    }

    private static function get_atts_for_shortcode($codeInfo)
    {
        $atts = isset($codeInfo['attrs']) ? $codeInfo['attrs'] : [];
        // add in missing default attributes
        $atts = shortcode_atts(WPRM_Template_Shortcodes::get_defaults($codeInfo['name']), $atts, str_replace('-', '_', $codeInfo['name']));
        if (!$atts['text_style']) {
            return $atts;
        }
        $classes = [
            'wprm-recipe-link',
            'wprm-block-text-' . $atts['text_style'],
            'wprm-recipe-icon',
        ];
        $style = 'color: ' . $atts['text_color'] . ' !important;';
        if ( 'text' !== $atts['style'] ) {
            $classes[] = 'wprm-recipe-link-' . $atts['style'];
            $classes[] = 'wprm-color-accent';
            $style .= 'background-color: ' . $atts['button_color'] . ';';
            $style .= 'border-color: ' . $atts['border_color'] . ';';
            $style .= 'border-radius: ' . $atts['border_radius'] . ';';
            $style .= 'padding: ' . $atts['vertical_padding'] . ' ' . $atts['horizontal_padding'] . ';';
        }
        else {
            $style .= 'background-color: initial; padding: 0;';
        }
        $atts['class'] = implode( ' ', $classes );
        $atts['style'] = $style;
        return $atts;
    }

}
?>